==> ejc-probid-api-3.0.0-20220715.083543-7-sources.jar: com/ejianc/business/calc/vo/CalcVO.java <==
package com.ejianc.business.calc.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 标前测算实体
 *
 * @author generator
 */
public class CalcVO extends BaseVO {
	private static final long serialVersionUID = 7801339174193006188L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	private Date registrationDeadline; // 报名截止日期
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String detailedAddress; // 工程地点(详细地址)
	private Long calcPriceModeId; // 计价方式id
	private String calcPriceModeCode; // 计价方式编码
	private String calcPriceModeName; // 计价方式名称
	private Long sourceBidTenderId; // 标书购买id
	private BigDecimal interceptTenderMny; // 拦标价
	private String totalInterceptTenderMnyFlag; // 是否为总拦标价 0-否、1-是
	private BigDecimal bidMny; // 投标金额
	private BigDecimal quoteFloatRate; // 报价下浮率
	private String projectOverview; // 项目概况
	private String memo; // 备注


	public Long getEmployeeId() {
		return employeeId;
	}

	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getDetailedAddress() {
		return detailedAddress;
	}

	public void setDetailedAddress(String detailedAddress) {
		this.detailedAddress = detailedAddress;
	}

	public Long getCalcPriceModeId() {
		return calcPriceModeId;
	}

	public void setCalcPriceModeId(Long calcPriceModeId) {
		this.calcPriceModeId = calcPriceModeId;
	}

	public String getCalcPriceModeCode() {
		return calcPriceModeCode;
	}

	public void setCalcPriceModeCode(String calcPriceModeCode) {
		this.calcPriceModeCode = calcPriceModeCode;
	}

	public String getCalcPriceModeName() {
		return calcPriceModeName;
	}

	public void setCalcPriceModeName(String calcPriceModeName) {
		this.calcPriceModeName = calcPriceModeName;
	}

	public Long getSourceBidTenderId() {
		return sourceBidTenderId;
	}

	public void setSourceBidTenderId(Long sourceBidTenderId) {
		this.sourceBidTenderId = sourceBidTenderId;
	}

	public BigDecimal getInterceptTenderMny() {
		return interceptTenderMny;
	}

	public void setInterceptTenderMny(BigDecimal interceptTenderMny) {
		this.interceptTenderMny = interceptTenderMny;
	}

	public String getTotalInterceptTenderMnyFlag() {
		return totalInterceptTenderMnyFlag;
	}

	public void setTotalInterceptTenderMnyFlag(String totalInterceptTenderMnyFlag) {
		this.totalInterceptTenderMnyFlag = totalInterceptTenderMnyFlag;
	}

	public BigDecimal getBidMny() {
		return bidMny;
	}

	public void setBidMny(BigDecimal bidMny) {
		this.bidMny = bidMny;
	}

	public BigDecimal getQuoteFloatRate() {
		return quoteFloatRate;
	}

	public void setQuoteFloatRate(BigDecimal quoteFloatRate) {
		this.quoteFloatRate = quoteFloatRate;
	}

	public String getProjectOverview() {
		return projectOverview;
	}

	public void setProjectOverview(String projectOverview) {
		this.projectOverview = projectOverview;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

}

==> ejc-probid-api-3.0.0-20221207.023812-82-sources.jar: com/ejianc/business/calc/vo/CalcVO.java <==
package com.ejianc.business.calc.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 标前测算实体
 *
 * @author generator
 */
public class CalcVO extends BaseVO {
	private static final long serialVersionUID = 7801339174193006188L;

	private Long employeeId; // 经办人id
	private String employeeName; // 经办人名称
	private Date commitDate; // 提交日期
	private String commitUserName; // 提交人名称
	private String commitUserCode; // 提交人账号
	private Date effectiveDate; // 生效日期
	private String billCode; // 单据编码
	private String billName; // 单据名称
	private String billType; // 单据类型
	private Integer billState; // 单据状态
	private String billStateName; // 单据状态名称
	private Long projectId; // 项目id
	private String projectCode; // 项目编码
	private String projectName; // 项目名称
	private String constructionUnit; // 建设单位
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date registrationDeadline; // 报名截止日期
	@JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date bidOpenDate; // 开标日期
	private Long bidUnitId; // 投标单位id
	private String bidUnitCode; // 投标单位编码
	private String bidUnitName; // 投标单位名称
	private String detailedAddress; // 工程地点(详细地址)
	private Long calcPriceModeId; // 计价方式id
	private String calcPriceModeCode; // 计价方式编码
	private String calcPriceModeName; // 计价方式名称
	private Long sourceBidTenderId; // 标书购买id
	private BigDecimal interceptTenderMny; // 拦标价
	private String totalInterceptTenderMnyFlag; // 是否为总拦标价 0-否、1-是
	private BigDecimal bidMny; // 投标金额
	private BigDecimal quoteFloatRate; // 报价下浮率
	private String projectOverview; // 项目概况
	private String memo; // 备注


	public Long getEmployeeId() {
		return employeeId;
	}

	@ReferDeserialTransfer
	public void setEmployeeId(Long employeeId) {
		this.employeeId = employeeId;
	}

	public String getEmployeeName() {
		return employeeName;
	}

	public void setEmployeeName(String employeeName) {
		this.employeeName = employeeName;
	}

	public Date getCommitDate() {
		return commitDate;
	}

	public void setCommitDate(Date commitDate) {
		this.commitDate = commitDate;
	}

	public String getCommitUserName() {
		return commitUserName;
	}

	public void setCommitUserName(String commitUserName) {
		this.commitUserName = commitUserName;
	}

	public String getCommitUserCode() {
		return commitUserCode;
	}

	public void setCommitUserCode(String commitUserCode) {
		this.commitUserCode = commitUserCode;
	}

	public Date getEffectiveDate() {
		return effectiveDate;
	}

	public void setEffectiveDate(Date effectiveDate) {
		this.effectiveDate = effectiveDate;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public String getBillName() {
		return billName;
	}

	public void setBillName(String billName) {
		this.billName = billName;
	}

	public String getBillType() {
		return billType;
	}

	public void setBillType(String billType) {
		this.billType = billType;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public String getBillStateName() {
		return billStateName;
	}

	public void setBillStateName(String billStateName) {
		this.billStateName = billStateName;
	}

	public Long getProjectId() {
		return projectId;
	}

	@ReferDeserialTransfer
	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectCode() {
		return projectCode;
	}

	public void setProjectCode(String projectCode) {
		this.projectCode = projectCode;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getConstructionUnit() {
		return constructionUnit;
	}

	public void setConstructionUnit(String constructionUnit) {
		this.constructionUnit = constructionUnit;
	}

	public Date getRegistrationDeadline() {
		return registrationDeadline;
	}

	public void setRegistrationDeadline(Date registrationDeadline) {
		this.registrationDeadline = registrationDeadline;
	}

	public Date getBidOpenDate() {
		return bidOpenDate;
	}

	public void setBidOpenDate(Date bidOpenDate) {
		this.bidOpenDate = bidOpenDate;
	}

	public Long getBidUnitId() {
		return bidUnitId;
	}

	public void setBidUnitId(Long bidUnitId) {
		this.bidUnitId = bidUnitId;
	}

	public String getBidUnitCode() {
		return bidUnitCode;
	}

	public void setBidUnitCode(String bidUnitCode) {
		this.bidUnitCode = bidUnitCode;
	}

	public String getBidUnitName() {
		return bidUnitName;
	}

	public void setBidUnitName(String bidUnitName) {
		this.bidUnitName = bidUnitName;
	}

	public String getDetailedAddress() {
		return detailedAddress;
	}

	public void setDetailedAddress(String detailedAddress) {
		this.detailedAddress = detailedAddress;
	}

	public Long getCalcPriceModeId() {
		return calcPriceModeId;
	}

	@ReferDeserialTransfer
	public void setCalcPriceModeId(Long calcPriceModeId) {
		this.calcPriceModeId = calcPriceModeId;
	}

	public String getCalcPriceModeCode() {
		return calcPriceModeCode;
	}

	public void setCalcPriceModeCode(String calcPriceModeCode) {
		this.calcPriceModeCode = calcPriceModeCode;
	}

	public String getCalcPriceModeName() {
		return calcPriceModeName;
	}

	public void setCalcPriceModeName(String calcPriceModeName) {
		this.calcPriceModeName = calcPriceModeName;
	}

	public Long getSourceBidTenderId() {
		return sourceBidTenderId;
	}

	public void setSourceBidTenderId(Long sourceBidTenderId) {
		this.sourceBidTenderId = sourceBidTenderId;
	}

	public BigDecimal getInterceptTenderMny() {
		return interceptTenderMny;
	}

	public void setInterceptTenderMny(BigDecimal interceptTenderMny) {
		this.interceptTenderMny = interceptTenderMny;
	}

	public String getTotalInterceptTenderMnyFlag() {
		return totalInterceptTenderMnyFlag;
	}

	public void setTotalInterceptTenderMnyFlag(String totalInterceptTenderMnyFlag) {
		this.totalInterceptTenderMnyFlag = totalInterceptTenderMnyFlag;
	}

	public BigDecimal getBidMny() {
		return bidMny;
	}

	public void setBidMny(BigDecimal bidMny) {
		this.bidMny = bidMny;
	}

	public BigDecimal getQuoteFloatRate() {
		return quoteFloatRate;
	}

	public void setQuoteFloatRate(BigDecimal quoteFloatRate) {
		this.quoteFloatRate = quoteFloatRate;
	}

	public String getProjectOverview() {
		return projectOverview;
	}

	public void setProjectOverview(String projectOverview) {
		this.projectOverview = projectOverview;
	}

	public String getMemo() {
		return memo;
	}

	public void setMemo(String memo) {
		this.memo = memo;
	}

}
